==> portability-auth-microsoft-0.1.5-sources.jar: org/datatransferproject/auth/microsoft/MicrosoftOAuthConfig.java <==
/*
 * Copyright 2018 The Data Transfer Project Authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.datatransferproject.auth.microsoft;

import com.google.common.collect.ImmutableMap;
import com.google.common.collect.ImmutableSet;
import java.util.Map;
import java.util.Set;
import org.datatransferproject.auth.OAuth2Config;

public class MicrosoftOAuthConfig implements OAuth2Config {

  @Override
  public String getServiceName() {
    return "Microsoft";
  }

  @Override
  public String getAuthUrl() {
    return "https://login.microsoftonline.com/common/oauth2/v2.0/authorize";
  }

  @Override
  public String getTokenUrl() {
    return "https://login.microsoftonline.com/common/oauth2/v2.0/token";
  }

  @Override
  public Map<String, Set<String>> getExportScopes() {
    return ImmutableMap.<String, Set<String>>builder()
        .put("MAIL", ImmutableSet.of("user.read", "Mail.Read"))
        .put("CONTACTS", ImmutableSet.of("user.read", "Contacts.Read"))
        .put("CALENDAR", ImmutableSet.of("user.read", "Calendars.Read"))
        .build();
  }

  @Override
  public Map<String, Set<String>> getImportScopes() {
    return ImmutableMap.<String, Set<String>>builder()
        .put("MAIL", ImmutableSet.of("user.read", "Mail.ReadWrite"))
        .put("CONTACTS", ImmutableSet.of("user.read", "Contacts.ReadWrite"))
        .put("CALENDAR", ImmutableSet.of("user.read", "Calendars.ReadWrite"))
        .build();
  }
}

==> portability-auth-microsoft-0.3.67-sources.jar: org/datatransferproject/auth/microsoft/MicrosoftOAuthConfig.java <==
/*
 * Copyright 2018 The Data Transfer Project Authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.datatransferproject.auth.microsoft;

import com.google.common.collect.ImmutableMap;
import com.google.common.collect.ImmutableSet;
import java.util.Map;
import java.util.Set;
import org.datatransferproject.auth.OAuth2Config;

public class MicrosoftOAuthConfig implements OAuth2Config {

  @Override
  public String getServiceName() {
    return "Microsoft";
  }

  @Override
  public String getAuthUrl() {
    return "https://login.microsoftonline.com/common/oauth2/v2.0/authorize";
  }

  @Override
  public String getTokenUrl() {
    return "https://login.microsoftonline.com/common/oauth2/v2.0/token";
  }

  @Override
  public Map<String, Set<String>> getExportScopes() {
    return ImmutableMap.<String, Set<String>>builder()
        .put("MAIL", ImmutableSet.of("user.read", "Mail.Read"))
        .put("CONTACTS", ImmutableSet.of("user.read", "Contacts.Read"))
        .put("CALENDAR", ImmutableSet.of("user.read", "Calendars.Read"))
        .put("PHOTOS", ImmutableSet.of("user.read", "Files.Read"))
        .build();
  }

  @Override
  public Map<String, Set<String>> getImportScopes() {
    return ImmutableMap.<String, Set<String>>builder()
        .put("MAIL", ImmutableSet.of("user.read", "Mail.ReadWrite"))
        .put("CONTACTS", ImmutableSet.of("user.read", "Contacts.ReadWrite"))
        .put("CALENDAR", ImmutableSet.of("user.read", "Calendars.ReadWrite"))
        .put("PHOTOS", ImmutableSet.of("user.read", "Files.ReadWrite"))
        .build();
  }
}
